@@ -1436,7 +1436,7 @@ class Experiment(object):
 
                 time = future
                 self.local_time += full_step
-                log.info('time: {}'.format(self.local_time))
+                # log.info('time: {}'.format(self.local_time))
 
                 if self.emit_step is None:
                     self.emit_data()
